==> apache-fineract-1.8.4-src.tar.gz: apache-fineract-src-1.8.4/fineract-provider/src/main/java/org/apache/fineract/infrastructure/creditbureau/data/CreditReportData.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.fineract.infrastructure.creditbureau.data;

import java.io.Serializable;

public final class CreditReportData implements Serializable {

    private final Long id;
    @SuppressWarnings("unused")
    private final Long creditBureauId;
    @SuppressWarnings("unused")
    private final String nationalId;

    public static CreditReportData instance(final Long id, final Long creditBureauId, final String nationalId) {
        return new CreditReportData(id, creditBureauId, nationalId);
    }

    private CreditReportData(final Long id, final Long creditBureauId, final String nationalId) {
        this.id = id;
        this.creditBureauId = creditBureauId;
        this.nationalId = nationalId;

    }
}

==> apache-fineract-1.9.0-src.tar.gz: apache-fineract-src-1.9.0/fineract-provider/src/main/java/org/apache/fineract/infrastructure/creditbureau/data/CreditReportData.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.fineract.infrastructure.creditbureau.data;

import java.io.Serializable;
import lombok.Data;
import lombok.NoArgsConstructor;
import lombok.experimental.Accessors;

@Data
@NoArgsConstructor
@Accessors(chain = true)
public final class CreditReportData implements Serializable {

    private static final long serialVersionUID = 1L;
    private Long id;
    @SuppressWarnings("unused")
    private Long creditBureauId;
    @SuppressWarnings("unused")
    private String nationalId;

    public static CreditReportData instance(final Long id, final Long creditBureauId, final String nationalId) {
        return new CreditReportData().setId(id).setCreditBureauId(creditBureauId).setNationalId(nationalId);
    }
}
